check_configuration

Function check_configuration 

pub fn check_configuration(
    layout: &Layout,
    configuration: &Configuration,
) -> Result<Vec<Finding>, DesignError>
The checks on one configuration’s motors in layout. The configuration need not be one of the rocket’s own, so a candidate motor can be checked before it is stored.

Errors

As Layout::place_motors.