pub fn shear_modulus(id: &str) -> Option<&'static BuiltinShearModulus>Expand description
The built-in shear modulus of the material with id, if a source gives one.
pub fn shear_modulus(id: &str) -> Option<&'static BuiltinShearModulus>The built-in shear modulus of the material with id, if a source gives one.