pub struct CenteringRing {
pub length_m: f64,
pub outer_radius_m: f64,
pub inner_radius_m: f64,
pub material: Material,
}Expand description
A flat annular ring, or a bulkhead when the inner radius is zero.
Fields
length_m: f64Thickness along the axis, m.
outer_radius_m: f64Outer radius, m.
inner_radius_m: f64Inner radius, m (zero for a bulkhead).
material: MaterialMaterial (bulk).
Implementations
Sourceimpl CenteringRing
impl CenteringRing
Sourcepub fn bulkhead(length_m: f64, radius_m: f64, material: Material) -> Self
pub fn bulkhead(length_m: f64, radius_m: f64, material: Material) -> Self
A bulkhead: a solid disc.
Sourcepub fn mass_properties(&self) -> Result<MassProperties, DesignError>
pub fn mass_properties(&self) -> Result<MassProperties, DesignError>
Mass properties in the ring’s frame.
Errors
Geometry and material errors, including an inner radius not below the outer.