NoseCone

Struct NoseCone 

pub struct NoseCone {
    pub shape: NoseShape,
    pub length_m: f64,
    pub base_radius_m: f64,
    pub wall: Wall,
    pub shoulder: Option<Shoulder>,
    pub material: Material,
}
A nose cone: a profile with its tip forward, and an optional shoulder aft of its base.

Fields

shape: NoseShape

Profile shape.

length_m: f64

Length from tip to base, m.

base_radius_m: f64

Base radius, m.

wall: Wall

Filled, or a wall of a thickness.

shoulder: Option<Shoulder>

Optional shoulder.

material: Material

Material (bulk).

Implementations

Source

impl NoseCone

pub fn profile(&self) -> Result<Profile, DesignError>

The outer profile.

Errors

As Profile::nose.

pub fn mass_properties(&self) -> Result<MassProperties, DesignError>

Mass properties in the nose cone’s frame (origin at the tip).

Errors

Geometry, material and numerical errors from the profile, the solid and the shoulder.