pub struct NoseCone {
pub shape: NoseShape,
pub length_m: f64,
pub base_radius_m: f64,
pub wall: Wall,
pub shoulder: Option<Shoulder>,
pub material: Material,
}Expand description
A nose cone: a profile with its tip forward, and an optional shoulder aft of its base.
Fields
shape: NoseShapeProfile shape.
length_m: f64Length from tip to base, m.
base_radius_m: f64Base radius, m.
wall: WallFilled, or a wall of a thickness.
shoulder: Option<Shoulder>Optional shoulder.
material: MaterialMaterial (bulk).
Implementations
Sourceimpl NoseCone
impl NoseCone
Sourcepub fn profile(&self) -> Result<Profile, DesignError>
pub fn profile(&self) -> Result<Profile, DesignError>
Sourcepub fn mass_properties(&self) -> Result<MassProperties, DesignError>
pub fn mass_properties(&self) -> Result<MassProperties, DesignError>
Mass properties in the nose cone’s frame (origin at the tip).
Errors
Geometry, material and numerical errors from the profile, the solid and the shoulder.